==> code-scan-complexity-0.0.1.tgz: package/lib/scan.js <==
//代码扫描
const fs = require("fs");
const glob = require("glob");

// 默认扫描扩展
const DEFAULT_EXTENSIONS = "/**/*.?(js|vue|jsx|ts|tsx)";

// 默认忽略文件夹
const DEFAULT_IGNORE_PATTERNS = [
  "node_modules/**",
  "build/**",
  "dist/**",
  "output/**",
  "common_build/**",
  ".history/**",
];

//默认参数配置
const DEFAULT_PARAM = {
  rootPath: process.cwd(),
  defalutIgnore: true,
  extensions: DEFAULT_EXTENSIONS,
  ignoreFileName: ".gitignore",
};

/**
 * 加载 ignore 配置文件，并处理成数组
 * @param {*} ignoreFileName
 */
const loadIgnorePatterns = (ignoreFileName) => {
  const ignorePath = `${process.cwd()}/${ignoreFileName}`;
  try {
    const ignores = fs.readFileSync(ignorePath, "utf8");
    return ignores.split(/[\n\r]|\n\r/).filter(Boolean);
  } catch (e) {
    console.error("loadIgnorePatterns：", e);
    return [];
  }
};

// 为每个忽略的文件加上前缀,使其生效
const getIgnoreFiles = (files) =>
  files.map((item) => `**/${item}/**`);

/**
 *
 * @param {*} param
 * extensions 需要扫描的扩展文件
 * rootPath 需要扫描的文件目录名
 * defalutIgnore 是否需要执行默认的文件忽略
 * ignoreFileName 忽略的文件夹及文件
 * @returns files
 */
module.exports = function codeScan(param) {
  param = Object.assign(DEFAULT_PARAM, param);
  const { extensions, defalutIgnore, ignoreFileName } = param;
  const rootPath = param.rootPath.includes(process.cwd())
    ? param.rootPath
    : process.cwd() + param.rootPath;
  const ignorePatterns = loadIgnorePatterns(ignoreFileName);
  const ignoreFiles = defalutIgnore
    ? getIgnoreFiles([...DEFAULT_IGNORE_PATTERNS, ...ignorePatterns])
    : getIgnoreFiles(ignorePatterns);

  return glob.sync(`${rootPath}${extensions}`, {
    ignore: ignoreFiles,
    dot: true,
  });
};

==> code-scan-complexity-0.0.2.tgz: package/lib/scan.js <==
//代码扫描
const fs = require("fs");
const glob = require("glob");

// 默认扫描扩展
const DEFAULT_EXTENSIONS = "/**/*.?(js|jsx|ts|tsx)";

// 默认忽略文件夹
const DEFAULT_IGNORE_PATTERNS = [
  "node_modules/**",
  "build/**",
  "dist/**",
  "output/**",
  "common_build/**",
  ".history/**",
];

//默认参数配置
const DEFAULT_PARAM = {
  rootPath: process.cwd(),
  defalutIgnore: true,
  extensions: DEFAULT_EXTENSIONS,
  ignoreFileName: ".gitignore",
};

/**
 * 加载 ignore 配置文件，并处理成数组
 * @param {*} ignoreFileName
 */
const loadIgnorePatterns = (rootPath, ignoreFileName) => {
  const ignorePath = `${rootPath}/${ignoreFileName}`;
  try {
    const ignores = fs.readFileSync(ignorePath, "utf8");
    return ignores.split(/[\n\r]|\n\r/).filter(Boolean);
  } catch (e) {
    console.error("loadIgnorePatterns:", e);
    return [];
  }
};

// 为每个忽略的文件加上前缀,使其生效
const getIgnoreFiles = (files) => files.map((item) => `**/${item}/**`);

/**
 *
 * @param {*} param
 * extensions 需要扫描的扩展文件
 * rootPath 需要扫描的文件目录名
 * defalutIgnore 是否需要执行默认的文件忽略
 * ignoreFileName 忽略的文件夹及文件
 * @returns files
 */
module.exports = function codeScan(param) {
  param = Object.assign(DEFAULT_PARAM, param);
  const { extensions, defalutIgnore, ignoreFileName } = param;
  const rootPath = param.rootPath.includes(process.cwd())
    ? param.rootPath
    : process.cwd() + param.rootPath;
  const ignorePatterns = loadIgnorePatterns(rootPath, ignoreFileName);
  const ignoreFiles = defalutIgnore
    ? getIgnoreFiles([...DEFAULT_IGNORE_PATTERNS, ...ignorePatterns])
    : getIgnoreFiles(ignorePatterns);

  return glob.sync(`${rootPath}${extensions}`, {
    ignore: ignoreFiles,
    dot: true,
  });
};
